@@ -8,7 +8,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,8 +30,8 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Platform/os2.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
-import win32
+__revision__ = "src/engine/SCons/Platform/os2.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
+from . import win32
 
 def generate(env):
     if 'ENV' not in env:
