@@ -8,7 +8,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Platform/posix.py 74b2c53bc42290e911b334a6b44f187da698a668 2017/11/14 13:16:53 bdbaddog"
+__revision__ = "src/engine/SCons/Platform/posix.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
 
 import errno
 import os
@@ -41,6 +41,8 @@ import select
 
 import SCons.Util
 from SCons.Platform import TempFileMunge
+from SCons.Platform.virtualenv import ImportVirtualenv
+from SCons.Platform.virtualenv import ignore_virtualenv, enable_virtualenv
 
 exitvalmap = {
     2 : 127,
@@ -48,7 +50,7 @@ exitvalmap = {
 }
 
 def escape(arg):
-    "escape shell special characters" 
+    """escape shell special characters"""
     slash = '\\'
     special = '"$'
 
@@ -119,6 +121,9 @@ def generate(env):
     # Must be able to have GCC and DMD work in the same build, so:
     env['__DRPATH'] = '$_DRPATH'
 
+    if enable_virtualenv and not ignore_virtualenv:
+        ImportVirtualenv(env)
+
 # Local Variables:
 # tab-width:4
 # indent-tabs-mode:nil
