@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/MSCommon/__init__.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/MSCommon/__init__.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
 
 __doc__ = """
 Common functions for Microsoft Visual Studio and Visual C/C++.
@@ -41,7 +41,8 @@ from SCons.Tool.MSCommon.sdk import mssdk_exists, \
 
 from SCons.Tool.MSCommon.vc import msvc_exists, \
                                    msvc_setup_env, \
-                                   msvc_setup_env_once
+                                   msvc_setup_env_once, \
+                                   msvc_version_to_maj_min
 
 from SCons.Tool.MSCommon.vs import get_default_version, \
                                    get_vs_by_version, \
