@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2016 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/javah.py rel_2.5.1:3735:9dc6cee5c168 2016/11/03 14:02:02 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/javah.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
 
 import os.path
 
@@ -40,6 +40,8 @@ import SCons.Builder
 import SCons.Node.FS
 import SCons.Tool.javac
 import SCons.Util
+from SCons.Tool.JavaCommon import get_java_install_dirs
+
 
 def emit_java_headers(target, source, env):
     """Create and return lists of Java stub header files that will
@@ -120,6 +122,14 @@ def generate(env):
     java_javah = SCons.Tool.CreateJavaHBuilder(env)
     java_javah.emitter = emit_java_headers
 
+    if env['PLATFORM'] == 'win32':
+        # Ensure that we have a proper path for clang
+        javah = SCons.Tool.find_program_path(env, 'javah',
+                                             default_paths=get_java_install_dirs(env['PLATFORM']))
+        if javah:
+            javah_bin_dir = os.path.dirname(javah)
+            env.AppendENVPath('PATH', javah_bin_dir)
+
     env['_JAVAHOUTFLAG']    = JavaHOutFlagGenerator
     env['JAVAH']            = 'javah'
     env['JAVAHFLAGS']       = SCons.Util.CLVar('')
