@@ -3,7 +3,7 @@
 Tool specific initialization of msginit tool.
 """
 
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -24,7 +24,7 @@ Tool specific initialization of msginit tool.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/msginit.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/msginit.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
 
 import SCons.Warnings
 import SCons.Builder
@@ -35,7 +35,7 @@ def _optional_no_translator_flag(env):
   """ Return '--no-translator' flag if we run *msginit(1)*  in non-interactive
       mode."""
   import SCons.Util
-  if env.has_key('POAUTOINIT'):
+  if 'POAUTOINIT' in env:
     autoinit = env['POAUTOINIT']
   else:
     autoinit = False
@@ -66,7 +66,7 @@ def _POInitBuilderWrapper(env, target=None, source=_null, **kw):
   if source is _null:
     if 'POTDOMAIN' in kw:
       domain = kw['POTDOMAIN']
-    elif env.has_key('POTDOMAIN'):
+    elif 'POTDOMAIN' in env:
       domain = env['POTDOMAIN']
     else:
       domain = 'messages'
@@ -77,8 +77,22 @@ def _POInitBuilderWrapper(env, target=None, source=_null, **kw):
 #############################################################################
 def generate(env,**kw):
   """ Generate the `msginit` tool """
+  import sys
+  import os
   import SCons.Util
+  import SCons.Tool
   from SCons.Tool.GettextCommon import _detect_msginit
+  from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
+  from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
+
+  if sys.platform == 'win32':
+      msginit = SCons.Tool.find_program_path(env, 'msginit', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS )
+      if msginit:
+          msginit_bin_dir = os.path.dirname(msginit)
+          env.AppendENVPath('PATH', msginit_bin_dir)
+      else:
+          SCons.Warnings.Warning('msginit tool requested, but binary not found in ENV PATH')
+
   try:
     env['MSGINIT'] = _detect_msginit(env)
   except:
