@@ -5,7 +5,7 @@ The main package for the SCons software construction utility.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,15 +27,15 @@ The main package for the SCons software construction utility.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/__init__.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 12:59:24 bdbaddog"
+__revision__ = "src/engine/SCons/__init__.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
 
-__version__ = "3.0.0"
+__version__ = "3.0.2"
 
-__build__ = "rel_3.0.0:4395:8972f6a2f699"
+__build__ = "425375072d7b582a2df0db815c8eaeaa489468ab"
 
-__buildsys__ = "ubuntu-16"
+__buildsys__ = "hpmicrodog"
 
-__date__ = "2017/09/18 12:59:24"
+__date__ = "2019-01-01 18:32:02"
 
 __developer__ = "bdbaddog"
 
